# This file was auto-generated by Fern from our API Definition.

import typing

from .conversations_list_response_conversation import ConversationsListResponseConversation
from .conversations_list_response_conversations import ConversationsListResponseConversations

ConversationsListResponse = typing.Union[ConversationsListResponseConversations, ConversationsListResponseConversation]
