# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ToolCallPayload(UniversalBaseModel):
    type: typing.Literal["tool_call"] = "tool_call"
    tool_call_id: str = pydantic.Field()
    """
    Unique ID for this tool call
    """

    tool_name: str = pydantic.Field()
    """
    Name of the tool to execute
    """

    parameters: typing.Dict[str, typing.Optional[typing.Any]] = pydantic.Field()
    """
    Parameters for tool execution
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
