# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .voices_get_response import VoicesGetResponse
from .voices_list_response import VoicesListResponse

__all__ = ["VoicesGetResponse", "VoicesListResponse"]
